@@ -29,7 +29,7 @@ def retrieve_all_data(
         raise TypeError("'model' must inherit from 'BaseSqlModel'.")
 
     statement = select(model)
-    if where_clause:
+    if where_clause is not None:
         statement = statement.where(where_clause)
 
     result = session.execute(statement=statement)
